#! Flux3D 19.1
newProject()
GeomMeshOptions[1].methodAutomaticMeshVolume=OptimizeMeshGemsActivated(level=OptimizationStandard())
openModelerContext()
closeModelerContext()

######parameter geometric##########
ParameterGeom(name='BILLET_HEIGHT',
              expression='250')
ParameterGeom(name='BILLET_RADIUS',
              expression='25')
ParameterGeom(name='COIL_RADIUS',
              expression='35')
ParameterGeom(name='COMP_LAYER_THICKNESS',
              expression='6')
ParameterGeom(name='POSITION_BILLET',
              expression='0')
ParameterGeom(name='SKIN_DEPTH',
              expression='4')

#######Mesh##################
MeshPoint(name='CENTER_BILLET',
          lengthUnit=LengthUnit['MILLIMETER'],
          value='BILLET_RADIUS/3',
          color=Color['Cyan'])

MeshPoint(name='BILLET',
          lengthUnit=LengthUnit['MILLIMETER'],
          value='BILLET_RADIUS/5',
          color=Color['Green'])

MeshPoint(name='INFINITE',
          lengthUnit=LengthUnit['MILLIMETER'],
          value='50',
          color=Color['Turquoise'])

MeshPoint(name='VACUUM',
          lengthUnit=LengthUnit['MILLIMETER'],
          value='40',
          color=Color['Yellow'])

MeshPoint(name='VACUUM_COMP',
          lengthUnit=LengthUnit['MILLIMETER'],
          value='20',
          color=Color['Red'])

MeshLineArithmetic(name='BILLET_HEIGHT_ML',
                   color=Color['Cyan'],
                   number=20)

MeshLineArithmetic(name='SKIN_DEPTH_ML',
                   color=Color['Magenta'],
                   number=2)


#####coordinate system#######
CoordSysCylindrical(name='BILLET',
                    parentCoordSys=GlobalUnits(lengthUnit=LengthUnit['MILLIMETER'],
                                               angleUnit=AngleUnit['DEGREE']),
                    origin=['0',
                            '0',
                            'POSITION_BILLET'],
                    rotationAngles=RotationAngles(angleX='0',
                                                  angleY='0',
                                                  angleZ='0'),
                    visibility=Visibility['VISIBLE'])

CoordSysCylindrical(name='COIL',
                    parentCoordSys=Local(coordSys=CoordSys['BILLET']),
                    origin=['0',
                            '0',
                            '-150'],
                    rotationAngles=RotationAngles(angleX='0',
                                                  angleY='0',
                                                  angleZ='0'),
                    visibility=Visibility['VISIBLE'])

#####create points###########
P1= PointCoordinates(color=Color['White'],
                 visibility=Visibility['VISIBLE'],
                 coordSys=CoordSys['BILLET'],
                 uvw=['0',
                      '0',
                      '-BILLET_HEIGHT/2'],
                 nature=Nature['STANDARD'],
                 mesh=MeshPoint['CENTER_BILLET'])

P2= PointCoordinates(color=Color['White'],
                 visibility=Visibility['VISIBLE'],
                 coordSys=CoordSys['BILLET'],
                 uvw=['BILLET_RADIUS-SKIN_DEPTH',
                      '0',
                      '-BILLET_HEIGHT/2'],
                 nature=Nature['STANDARD'],
                 mesh=MeshPoint['BILLET'])

P3= PointCoordinates(color=Color['White'],
                 visibility=Visibility['VISIBLE'],
                 coordSys=CoordSys['BILLET'],
                 uvw=['BILLET_RADIUS',
                      '0',
                      '-BILLET_HEIGHT/2'],
                 nature=Nature['STANDARD'],
                 mesh=MeshPoint['BILLET'])

P4= PointCoordinates(color=Color['White'],
                 visibility=Visibility['VISIBLE'],
                 coordSys=CoordSys['BILLET'],
                 uvw=['BILLET_RADIUS+COMP_LAYER_THICKNESS',
                      '0',
                      '-BILLET_HEIGHT/2'],
                 nature=Nature['STANDARD'],
                 mesh=MeshPoint['BILLET'])

#####transformation############

TransfTranslationVector(name='BILLET_HEIGHT',
                        coordSys=CoordSys['BILLET'],
                        vector=['0',
                                '0',
                                'BILLET_HEIGHT'])

TransfTranslationVector(name='COMP_HEIGTH_TR',
                        coordSys=CoordSys['XYZ1'],
                        vector=['0',
                                '0',
                                '2.4*BILLET_HEIGHT'])

TransfTranslationVector(name='COMP_HEIGTH_TR_NEG',
                        coordSys=CoordSys['BILLET'],
                        vector=['0',
                                '0',
                                '-1.2*BILLET_HEIGHT'])

TransfRotation3AnglesPivotPoint(name='ROT_BILLET_BASIS',
                                coordSys=CoordSys['BILLET'],
                                pivotPoint=Point[1],
                                rotationAngles=RotationAngles(angleX='0',
                                                              angleY='0',
                                                              angleZ='90'))

TransfRotation3AnglesPivotPoint(name='ROT_BILLET_BASIS_NEG',
                                coordSys=CoordSys['BILLET'],
                                pivotPoint=Point[1],
                                rotationAngles=RotationAngles(angleX='0',
                                                              angleY='0',
                                                              angleZ='-90'))

####create lines ###########

lastInstance = LineSegment(color=Color['White'],
            visibility=Visibility['VISIBLE'],
            defPoint=[P1,
                      P2],
            nature=Nature['STANDARD'])

lastInstance = LineSegment(color=Color['White'],
            visibility=Visibility['VISIBLE'],
            defPoint=[P2,
                      P3],
            nature=Nature['STANDARD'])


result = LineSegment[1].extrude(transformation=Transf['ROT_BILLET_BASIS'],
        repetitionNumber=4,
        extrusionType='standard',
        buildingOption='Faces')

result = LineSegment[2].extrude(transformation=Transf['ROT_BILLET_BASIS'],
        repetitionNumber=4,
        extrusionType='standard',
        buildingOption='FacesWithMeshGenerator')



result = PointCoordinates[4].extrude(transformation=Transf['ROT_BILLET_BASIS'],
        repetitionNumber=4,
        extrusionType='standard')

result = FaceStructured[ALL].extrude(transformation=Transf['BILLET_HEIGHT'],
        repetitionNumber=1,
        extrusionType='standard',
        buildingOption='VolumesWithMeshGenerator')


result = LineExtruded[20,17,19,18].extrude(transformation=Transf['BILLET_HEIGHT'],
        repetitionNumber=1,
        extrusionType='standard',
        buildingOption='Faces')

result = LinePropagated[48,50,53,52].extrude(transformation=Transf['COMP_HEIGTH_TR'],
        repetitionNumber=1,
        extrusionType='standard',
        buildingOption='Faces')

result = LineExtruded[20,19,18,17].extrude(transformation=Transf['COMP_HEIGTH_TR_NEG'],
        repetitionNumber=1,
        extrusionType='standard',
        buildingOption='Faces')
        

buildFaces()

FaceAutomatic[46].deleteForce()
FaceAutomatic[45].deleteForce()

buildVolumes()

PointPropagated[32,31,33,34,28,30,27,29].mesh=MeshPoint['VACUUM_COMP']
Point[11,5,8,6,9,12,10,7,13,2,4,3,25,26,23,24].mesh=MeshPoint['BILLET']

LineExtruded[34,36,42,39,22,24,27,30,21].mesh=MeshLine['BILLET_HEIGHT_ML']

Line[13,15,2,11,44,35,38,41].mesh=MeshLine['SKIN_DEPTH_ML']

#######Infinite box############

InfiniteBoxCylinderZ(size=['4*BILLET_RADIUS',
                           '5*BILLET_RADIUS',
                           '3*BILLET_HEIGHT',
                           '3.1*BILLET_HEIGHT'])
InfiniteBoxCylinderZ['InfiniteBoxCylinderZ'].complete3D(buildingOption='Volumes',
           coordSys=CoordSys['BILLET'],
           linkMesh='LinkMesh')

PointInfiniteBox[59,60,61,62,64,65,66,57,58,52,51,53,54,55,56,63].mesh=MeshPoint['INFINITE']
PointInfiniteBox[46,47,48,49,50,43,44,45,37,38,39,40,41,42,35,36].mesh=MeshPoint['VACUUM']
InfiniteBoxCylinderZ['InfiniteBoxCylinderZ'].setInvisible()

MeshGeneratorBoundaryLayers(name='SKIN_DEPTH',

                            heightType=AllLayer(heightOfAllLayers='0.37513E-3'),

                            numberOfLayers=3,

                            geometricProgression=1.2,

                            dominantElement=Tetrahedron())



Volume[8,4,7,3,2,6,1,5].meshGenerator=MeshGenerator['SKIN_DEPTH']

AidedMesh[1].aidedMeshState=AidedMeshInactivated()

meshDomain()

saveProjectAs('geomeshbuilt.FLU')

