#! Flux3D 19.1


## Application
lastInstance = ApplicationMagneticACThermal3D(frequency='3000',
                               temperatureUnit=Unit['CELSIUS_DEGREE'],
                               coilCoefficient=CoilCoefficientAutomatic(),
                               formulationModel=MagneticACFormulationModelAutomatic(approximation=VectorPotentialApproximationEdge()),
                               scalarVariableOrder=ScalarVariableAutomaticOrder(),
                               vectorVariableOrder=VectorNodalVariableAutomaticOrder(),
                               transientInitialization=TransientInitializationZeroInitialSolution())

## Creation of materials

Material(name='MILD_STEEL : AISI1005',

         propertyBH=PropertyBhTdependentNonlinearJmu(js='1.9',

                                                     initialMur='300',

                                                     coeffT=TemperatureCoefficientExponentiel(tau=Temperature(temperature='150',

                                                                                                              unit=Unit['CELSIUS_DEGREE']),

                                                                                              tCurie=Temperature(temperature='760',

                                                                                                                 unit=Unit['CELSIUS_DEGREE'])),

                                                     temperature=Temperature(temperature='0',

                                                                             unit=Unit['CELSIUS_DEGREE'])),

         propertyJE=PropertyJeTLinearFunction(slope='0.001',

                                              rhoConstant='0.5E-6',

                                              referenceTemperature=Temperature(temperature='20',

                                                                               unit=Unit['CELSIUS_DEGREE']),

                                              temperature=Temperature(temperature='0',

                                                                      unit=Unit['CELSIUS_DEGREE'])),

         thermalConductivity=KtIsotropicTExponentialFunction(ka='25',

                                                             kb='15',

                                                             referenceTemperature=Temperature(temperature='0',

                                                                                              unit=Unit['CELSIUS_DEGREE']),

                                                             tau=Temperature(temperature='300',

                                                                             unit=Unit['CELSIUS_DEGREE'])),

         specificHeat=RhoCpTGaussFunction(energyTransition='5E8',

                                          rhoCpa='4E6',

                                          sigma='150',

                                          temperatureTransition=Temperature(temperature='760',

                                                                            unit=Unit['CELSIUS_DEGREE'])))


####Spatial quantity
SpatialParameterFormula(name='COORD_Z',
                        SpatialFormula='Z*1000')

SpatialParameterFormula(name='HA',
                        SpatialFormula='20')

SpatialParameterFormula(name='HA_FINA',
                        SpatialFormula='10000')


## Creation of mechanical sets
MechanicalSetCompressibleRemeshing(name='COMPRESSIBLE')
MechanicalSetFixed(name='FIXED')
MechanicalSetTranslation1Axis(name='TRANSLATION',
                              kinematics=LinearImposedSpeed(velocity='0.05',
                                                            initialPosition='-0.25',
                                                            internalCharacteristics=LinearLoadFormula(mass='0',
                                                                                                      force=FrictionFormula(value='0'))),
                              translationAxis=TranslationZAxis(coordSys=CoordSys['BILLET']))

#####circuit#################

CurrentStrandedCoil(name='SOURCE',
                    rmsModulus='350',
                    phase='0')

## Creation of face regions     

RegionFace(name='EXCHANGE',
           magneticACThermal3D=MagneticACThermal3DFace(thermalType=Thermal3DFaceThermalExchange(coefExchange=ExchangeSpatial(tExternal=ioTemperature(temperature='20',
                                                                                                                                                     unit=Unit['CELSIUS_DEGREE']),
                                                                                                                             spatialFormula=['HA+(HA_FINA-HA)*Valid(COORD_Z,250/2,250*2)',
                                                                                                                                             '0.5'])),
                                                       magneticType=MagneticAC3DFaceInactive()),
           color=Color['Red'],
           visibility=Visibility['VISIBLE'],
           mechanicalSet=MechanicalSet['TRANSLATION'])

## Creation of volume regions     

RegionVolume(name='AIR_COMPRESSIBLE',
             magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeInactive(transparency='automatic'),
                                                           magneticType=MagneticAC3DVolumeVacuum(formulation=Formulation['MD3SCRHJ'])),
             color=Color['Cyan'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['COMPRESSIBLE'])

RegionVolume(name='AIR_FIXE',
             magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeInactive(transparency='automatic'),
                                                           magneticType=MagneticAC3DVolumeVacuum(formulation=Formulation['MD3SCRHJ'])),
             color=Color['Turquoise'],
             visibility=Visibility['INVISIBLE'],
             mechanicalSet=MechanicalSet['FIXED'])

RegionVolume(name='BILLET',
             magneticACThermal3D=magneticACThermal3DVolume(thermalType=Thermal3DVolumeThermalConductor(transparency='automatic',
                                                                                                       heat=VolumeHeatSourceJouleEffectValue()),
                                                           magneticType=MagneticAC3DVolumeSolidConductor(formulation=Formulation['MD3TWOM']),
                                                           material=Material['MILD_STEEL']),
             color=Color['Green'],
             visibility=Visibility['VISIBLE'],
             mechanicalSet=MechanicalSet['TRANSLATION'])

## Assign regions to volumes
assignRegionToVolumes(volume=[Volume[12],
                              Volume[13],
                              Volume[11],
                              Volume[14],
                              Volume[15],
                              Volume[16]],
                      region=RegionVolume['AIR_FIXE'])

assignRegionToVolumes(volume=[Volume[10]],
                      region=RegionVolume['AIR_FIXE'])

assignRegionToVolumes(volume=[Volume[9]],
                      region=RegionVolume['AIR_COMPRESSIBLE'])


assignRegionToVolumes(volume=[Volume[5],
                              Volume[8],
                              Volume[1],
                              Volume[2],
                              Volume[3],
                              Volume[7],
                              Volume[4],
                              Volume[6]],
                      region=RegionVolume['BILLET'])


## Asign face region

FaceStructured[25,6,2,1,5,7,3,4,8,31,22,20,18,15,12,24,32,30,27,28].region=RegionFace['EXCHANGE']


##Non meshed coil
ComposedCoil(name='COIL_1',
             strandedCoil=CoilConductor['SOURCE'],
             turnNumber='10',
             seriesOrParallel=AllInSeries(),
             coilDuplicationBySymmetriesPeriodicities=CoilDuplication(),
             coordSys=CoordSys['COIL'],
             coilPath=OpenPathCoil(coilPoints=[CoilPoint(coordinates=['35',
                                                                      '3150',
                                                                      '50'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3195',
                                                                      '52'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3240',
                                                                      '54'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3285',
                                                                      '56'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3330',
                                                                      '58'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3375',
                                                                      '60'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3420',
                                                                      '62'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3465',
                                                                      '64'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3510',
                                                                      '66'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3555',
                                                                      '68'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3600',
                                                                      '70'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3645',
                                                                      '72'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3690',
                                                                      '74'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3735',
                                                                      '76'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3780',
                                                                      '78'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3825',
                                                                      '80'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3870',
                                                                      '82'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3915',
                                                                      '84'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '3960',
                                                                      '86'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4005',
                                                                      '88'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4050',
                                                                      '90'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4095',
                                                                      '92'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4140',
                                                                      '94'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4185',
                                                                      '96'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4230',
                                                                      '98'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4275',
                                                                      '100'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4320',
                                                                      '102'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4365',
                                                                      '104'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4410',
                                                                      '106'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4455',
                                                                      '108'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4500',
                                                                      '110'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4545',
                                                                      '112'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4590',
                                                                      '114'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4635',
                                                                      '116'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4680',
                                                                      '118'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4725',
                                                                      '120'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4770',
                                                                      '122'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4815',
                                                                      '124'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4860',
                                                                      '126'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4905',
                                                                      '128'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4950',
                                                                      '130'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '4995',
                                                                      '132'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5040',
                                                                      '134'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5085',
                                                                      '136'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5130',
                                                                      '138'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5175',
                                                                      '140'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5220',
                                                                      '142'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5265',
                                                                      '144'],
                                                         radius='30'),
                                               CoilPoint(coordinates=['35',
                                                                      '5310',
                                                                      '146'],
                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5355',

                                                                      '148'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5400',

                                                                      '150'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5445',

                                                                      '152'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5490',

                                                                      '154'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5535',

                                                                      '156'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5580',

                                                                      '158'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5625',

                                                                      '160'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5670',

                                                                      '162'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5715',

                                                                      '164'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5760',

                                                                      '166'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5805',

                                                                      '168'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5850',

                                                                      '170'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5895',

                                                                      '172'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5940',

                                                                      '174'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '5985',

                                                                      '176'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6030',

                                                                      '178'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6075',

                                                                      '180'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6120',

                                                                      '182'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6165',

                                                                      '184'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6210',

                                                                      '186'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6255',

                                                                      '188'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6300',

                                                                      '190'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6345',

                                                                      '192'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6390',

                                                                      '194'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6435',

                                                                      '196'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6480',

                                                                      '198'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6525',

                                                                      '200'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6570',

                                                                      '202'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6615',

                                                                      '204'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6660',

                                                                      '206'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6705',

                                                                      '208'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6750',

                                                                      '210'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6795',

                                                                      '212'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6840',

                                                                      '214'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6885',

                                                                      '216'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6930',

                                                                      '218'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '6975',

                                                                      '220'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7020',

                                                                      '222'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7065',

                                                                      '224'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7110',

                                                                      '226'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7155',

                                                                      '228'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7200',

                                                                      '230'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7245',

                                                                      '232'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7290',

                                                                      '234'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7335',

                                                                      '236'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7380',

                                                                      '238'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7425',

                                                                      '240'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7470',

                                                                      '242'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7515',

                                                                      '244'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7560',

                                                                      '246'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7605',

                                                                      '248'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7650',

                                                                      '250'],

                                                         radius='30'),

                                               CoilPoint(coordinates=['35',

                                                                      '7695',

                                                                      '252'],

                                                         radius='30')]),

             section=DiscCoilSection(sectionRadius='5'),

             mechanicalSet=MechanicalSet['FIXED'],

             resistivity='0.0000000168',

             volumicMass='1.0',

             aspect=ASPECT['OPAQUE_MAT'],

             color=Color['Red'],

             visibility=Visibility['VISIBLE'])

## create sensors
SensorPonctual(name='T_UP_EXT',

               spatialFormula='TCelsius',

               uvw=['BILLET_RADIUS',

                    '0',

                    'BILLET_HEIGHT/2'],

               coordSys=CoordSys['BILLET'],

               regionVolume='BILLET',

               constraint='POINT[19]',

               mechanicalSet=MechanicalSet['TRANSLATION'])


SensorPonctual(name='T_CENTER_EXT',

               spatialFormula='TCelsius',

               uvw=['BILLET_RADIUS',

                    '0',

                    '0'],

               coordSys=CoordSys['BILLET'],

               regionVolume='BILLET',

               constraint='LINE[34]',

               mechanicalSet=MechanicalSet['TRANSLATION'])


SensorPonctual(name='T_DOWN_EXT',

               spatialFormula='TCelsius',

               uvw=['BILLET_RADIUS',

                    '0',

                    '-BILLET_HEIGHT/2'],

               coordSys=CoordSys['BILLET'],

               regionVolume='BILLET',

               constraint='POINT[3]',

               mechanicalSet=MechanicalSet['TRANSLATION'])


result = checkPhysic()

saveProjectAs('physbuilt.FLU')

